@@ -29,7 +29,7 @@ import numpy
 from collections import defaultdict
 
 # hwrt modules
-from HandwrittenData import HandwrittenData  # Needed because of pickle
+from . import HandwrittenData  # Needed because of pickle
 from . import preprocessing  # Needed because of pickle
 from . import features
 from . import data_multiplication
